@@ -1166,7 +1166,7 @@ getgroup(const struct server *current_server,
 	}
 	c = NULL;
 	n = 9;			/* "other" header */
-	while ((l = getfoldedline(nntpin)) && *l && strcmp(l, ".")) {
+	while ((l = getfoldedline(nntpin, mgetaline)) && *l && strcmp(l, ".")) {
 	    /* regexp pattern matching */
 	    if (filterfile && dofilter(l)) {
 		killed++;
